@@ -21,10 +21,12 @@ class CollectGeometry(pyblish.api.ContextPlugin):
 
         assert project, 'Project not found'
 
-        geo_meshes = cmds.ls(type='mesh')
-        geo_transforms = [cmds.listRelatives(mesh, parent=True)[0] for mesh in geo_meshes]
+        geo_meshes = cmds.ls(type='mesh', long=True)
+        geo_transforms = [cmds.listRelatives(mesh, parent=True, fullPath=True)[0] for mesh in geo_meshes]
 
         for node in geo_transforms:
-            instance = context.create_instance(node, project=project)
+            node_name = node.split('|')[-1].split(':')[-1]
+            instance = context.create_instance(node_name, project=project)
+            instance.data['icon'] = 'cubes'
             instance.data['node'] = node
             instance.data['family'] = 'geometry'
